@@ -135,4 +135,4 @@ class PayboxProviderOptions(BaseModel):
     merchant_id: int
     secret: str
     site_url: HttpUrl
-    testing_mode: PayboxOnOff = PayboxOnOff.ON
+    testing_mode: int # PayboxOnOff
